@@ -26,7 +26,7 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtksignal.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas.h>
 #include "e-cell-checkbox.h"
 #include "gal/util/e-util.h"
 #include "e-table-item.h"
@@ -59,7 +59,7 @@ E_MAKE_TYPE(e_cell_checkbox, "ECellCheckbox", ECellCheckbox, e_cell_checkbox_cla
 ECell *
 e_cell_checkbox_new (void)
 {
-	ECellCheckbox *eccb = gtk_type_new (e_cell_checkbox_get_type ());
+	ECellCheckbox *eccb = g_object_new (E_CELL_CHECKBOX_TYPE, NULL);
 
 	e_cell_toggle_construct (E_CELL_TOGGLE (eccb), 2, 2, checks);
       
