@@ -25,18 +25,22 @@
 #ifndef _E_TABLE_CONFIG_H_
 #define _E_TABLE_CONFIG_H_
 
-#include <libgnome/gnome-defs.h>
 #include <gal/e-table/e-table-sort-info.h>
 #include <gal/e-table/e-table-specification.h>
 #include <gal/widgets/gtk-combo-text.h>
+#include <gal/e-table/e-table-without.h>
+#include <gal/e-table/e-table-subset-variable.h>
+#include <gal/e-table/e-table.h>
+#include <gtk/gtkwindow.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_TABLE_CONFIG_TYPE        (e_table_config_get_type ())
-#define E_TABLE_CONFIG(o)          (GTK_CHECK_CAST ((o), E_TABLE_CONFIG_TYPE, ETableConfig))
-#define E_TABLE_CONFIG_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TABLE_CONFIG_TYPE, ETableConfigClass))
-#define E_IS_TABLE_CONFIG(o)       (GTK_CHECK_TYPE ((o), E_TABLE_CONFIG_TYPE))
-#define E_IS_TABLE_CONFIG_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TABLE_CONFIG_TYPE))
+#define E_TABLE_CONFIG(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TABLE_CONFIG_TYPE, ETableConfig))
+#define E_TABLE_CONFIG_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TABLE_CONFIG_TYPE, ETableConfigClass))
+#define E_IS_TABLE_CONFIG(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TABLE_CONFIG_TYPE))
+#define E_IS_TABLE_CONFIG_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TABLE_CONFIG_TYPE))
+#define E_TABLE_CONFIG_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS((o), E_TABLE_CONFIG_TYPE, ETableConfigClass))
 
 typedef struct {
 	GtkComboText *combo;
@@ -50,7 +54,9 @@ typedef struct {
 
 
 typedef struct {
-	GtkObject parent;
+	GObject parent;
+
+	char *header;
 
 	/*
 	 * Our various dialog boxes
@@ -73,6 +79,12 @@ typedef struct {
 	ETableConfigSortWidgets sort [4];
 	ETableConfigSortWidgets group [4];
 
+	ETable               *available;
+	ETableWithout        *available_model;
+	ETable               *shown;
+	ETableSubsetVariable *shown_model;
+	char *domain;
+
 	/*
 	 * List of valid column names
 	 */
@@ -80,22 +92,24 @@ typedef struct {
 } ETableConfig;
 
 typedef struct {
-	GtkObjectClass parent_class;
+	GObjectClass parent_class;
 
 	/* Signals */
 	void        (*changed)        (ETableConfig *config);
 } ETableConfigClass;
 
-GtkType       e_table_config_get_type  (void);
+GType         e_table_config_get_type  (void);
 ETableConfig *e_table_config_new       (const char          *header,
 					ETableSpecification *spec,
-					ETableState         *state);
+					ETableState         *state,
+					GtkWindow           *parent_window);
 ETableConfig *e_table_config_construct (ETableConfig        *etco,
 					const char          *header,
 					ETableSpecification *spec,
-					ETableState         *state);
+					ETableState         *state,
+					GtkWindow           *parent_window);
 void          e_table_config_raise     (ETableConfig        *config);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_TABLE_CONFIG_H */
