@@ -271,7 +271,7 @@ eti_get_cell_background_color (ETableItem *eti, int row, int col, gboolean selec
 				background = gdk_color_copy (background);
 				allocated = TRUE;
 			}
-			e_hsv_tweak (background, 0.0f, 0.0f, -0.05f);
+			e_hsv_tweak (background, 0.0f, 0.0f, -0.07f);
 			gdk_color_alloc (gtk_widget_get_colormap (GTK_WIDGET (canvas)), background);
 		}
 	}
@@ -2233,6 +2233,9 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 	gboolean leave = FALSE;
 #endif
 
+	if (!eti->header)
+		return FALSE;
+
 	switch (e->type){
 	case GDK_BUTTON_PRESS: {
 		double x1, y1;
@@ -2542,7 +2545,7 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 
 #ifdef DO_TOOLTIPS
 		if (!g_getenv ("GAL_DONT_DO_TOOLTIPS")) {
-			if (eti->tooltip->timer > 0)
+			if (eti->tooltip->timer)
 				gtk_timeout_remove (eti->tooltip->timer);
 			eti->tooltip->col = col;
 			eti->tooltip->row = row;
@@ -2776,7 +2779,7 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 		d(leave = TRUE);
 	case GDK_ENTER_NOTIFY:
 		d(g_print("%s: %s received\n", __FUNCTION__, leave ? "GDK_LEAVE_NOTIFY" : "GDK_ENTER_NOTIFY"));
-		if (eti->tooltip->timer > 0)
+		if (eti->tooltip->timer)
 			gtk_timeout_remove (eti->tooltip->timer);
 		eti->tooltip->timer = 0;
 		break;
@@ -3121,7 +3124,7 @@ eti_cursor_change (ESelectionModel *selection, int row, int col, ETableItem *eti
 	if (eti->old_cursor_row != -1 && view_row != eti->old_cursor_row)
 		e_table_item_redraw_row (eti, eti->old_cursor_row);
 
-	if (view_row == -1 || view_col == -1) {
+	if (view_row == -1) {
 		e_table_item_leave_edit_(eti);
 		eti->old_cursor_row = -1;
 		return;
