@@ -24,7 +24,6 @@
 #ifndef _E_ICON_BAR_H_
 #define _E_ICON_BAR_H_
 
-#include <gdk_imlib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gal/widgets/e-canvas.h>
 
@@ -85,9 +84,10 @@ typedef enum
 } EIconBarColors;
 
 
-#define E_ICON_BAR(obj)          GTK_CHECK_CAST (obj, e_icon_bar_get_type (), EIconBar)
-#define E_ICON_BAR_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, e_icon_bar_get_type (), EIconBarClass)
-#define E_IS_ICON_BAR(obj)       GTK_CHECK_TYPE (obj, e_icon_bar_get_type ())
+#define E_ICON_BAR_TYPE          (e_icon_bar_get_type ())
+#define E_ICON_BAR(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, e_icon_bar_get_type (), EIconBar)
+#define E_ICON_BAR_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, e_icon_bar_get_type (), EIconBarClass)
+#define E_IS_ICON_BAR(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, e_icon_bar_get_type ())
 
 
 typedef struct _EIconBar       EIconBar;
