@@ -418,13 +418,20 @@ e_strstrcase (const gchar *haystack, const gchar *needle)
 void
 e_filename_make_safe (gchar *string)
 {
-	gchar *p;
+	gchar *p, *ts;
+	gunichar c;
 	
 	g_return_if_fail (string != NULL);
-	
-	for (p = string; *p; p++) {
-		if (!isprint ((unsigned char)*p) || strchr (" /'\"`&();|<>$%{}!", *p))
-			*p = '_';
+	p = string;
+
+	while(p && *p) {
+		c = g_utf8_get_char (p);
+		ts = p;
+		p = g_utf8_next_char (p);
+		if (!g_unichar_isprint(c) || ( c < 0xff && strchr (" /'\"`&();|<>$%{}!", c&0xff ))) {
+			while (ts<p) 	
+				*ts++ = '_';
+		}
 	}
 }
 
@@ -771,10 +778,25 @@ size_t e_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
 size_t 
 e_utf8_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
 {
-	size_t sz;
-	char *locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
-	size_t ret = e_strftime(s, max, locale_fmt, tm);
-	char *buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
+	size_t sz, ret;
+	char *locale_fmt, *buf;
+
+	locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
+	if (!locale_fmt)
+		return 0;
+
+	ret = e_strftime(s, max, locale_fmt, tm);
+	if (!ret) {
+		g_free (locale_fmt);
+		return 0;
+	}
+
+	buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
+	if (!buf) {
+		g_free (locale_fmt);
+		return 0;
+	}
+
 	if (sz >= max) {
 		char *tmp = buf + max - 1;
 		tmp = g_utf8_find_prev_char(buf, tmp);
@@ -854,10 +876,25 @@ size_t e_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct t
 size_t 
 e_utf8_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct tm *tm)
 {
-	size_t sz;
-	char *locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
-	size_t ret = e_strftime_fix_am_pm(s, max, locale_fmt, tm);
-	char *buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
+	size_t sz, ret;
+	char *locale_fmt, *buf;
+
+	locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
+	if (!locale_fmt)
+		return 0;
+
+	ret = e_strftime_fix_am_pm(s, max, locale_fmt, tm);
+	if (!ret) {
+		g_free (locale_fmt);
+		return 0;
+	}
+
+	buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
+	if (!buf) {
+		g_free (locale_fmt);
+		return 0;
+	}
+
 	if (sz >= max) {
 		char *tmp = buf + max - 1;
 		tmp = g_utf8_find_prev_char(buf, tmp);
