@@ -270,7 +270,6 @@ e_categories_button_clicked (GtkWidget *button,
 		categories->priv->ecmld = e_categories_master_list_dialog_new (categories->priv->ecml);
 		g_object_weak_ref (G_OBJECT (categories->priv->ecmld),
 				   ecmld_destroyed, categories);
-		g_object_ref (categories->priv->ecmld);
 	}
 }
 
@@ -544,8 +543,8 @@ e_categories_construct (ECategories *categories,
 		categories->priv->gui = gui;
 
 		gtk_dialog_add_buttons (GTK_DIALOG (categories),
-					GTK_STOCK_OK, GTK_RESPONSE_OK,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					GTK_STOCK_OK, GTK_RESPONSE_OK,
 					NULL);
 
 		gtk_dialog_set_default_response (GTK_DIALOG (categories),
@@ -556,7 +555,9 @@ e_categories_construct (ECategories *categories,
 		table = glade_xml_get_widget(gui, "table-categories");
 		gtk_widget_ref(table);
 		gtk_container_remove(GTK_CONTAINER(table->parent), table);
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (categories)->vbox), table, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (categories)->vbox), table, TRUE, TRUE, 6);
+		gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (categories)->vbox), 6);
+
 		gtk_widget_unref(table);
 
 		categories->priv->entry = glade_xml_get_widget(gui, "entry-categories");
