@@ -27,7 +27,7 @@
 #include <glib.h>
 #include <gtk/gtktypeutils.h>
 #include <gtk/gtkwidget.h>
-#include <libgnomeui/gnome-dialog.h>
+#include <gtk/gtkdialog.h>
 #include <glade/glade.h>
 #include <gal/e-table/e-table-model.h>
 
@@ -45,10 +45,10 @@ extern "C" {
  */
 
 #define E_CATEGORIES_TYPE			(e_categories_get_type ())
-#define E_CATEGORIES(obj)			(GTK_CHECK_CAST ((obj), E_CATEGORIES_TYPE, ECategories))
-#define E_CATEGORIES_CLASS(klass)		(GTK_CHECK_CLASS_CAST ((klass), E_CATEGORIES_TYPE, ECategoriesClass))
-#define E_IS_CATEGORIES(obj)		        (GTK_CHECK_TYPE ((obj), E_CATEGORIES_TYPE))
-#define E_IS_CATEGORIES_CLASS(klass)	        (GTK_CHECK_CLASS_TYPE ((obj), E_CATEGORIES_TYPE))
+#define E_CATEGORIES(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), E_CATEGORIES_TYPE, ECategories))
+#define E_CATEGORIES_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), E_CATEGORIES_TYPE, ECategoriesClass))
+#define E_IS_CATEGORIES(obj)		        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_CATEGORIES_TYPE))
+#define E_IS_CATEGORIES_CLASS(klass)	        (G_TYPE_CHECK_CLASS_TYPE ((obj), E_CATEGORIES_TYPE))
 
 
 typedef struct _ECategories       ECategories;
@@ -57,18 +57,18 @@ typedef struct _ECategoriesPriv   ECategoriesPriv;
 
 struct _ECategories
 {
-	GnomeDialog parent;
+	GtkDialog parent;
 
 	ECategoriesPriv *priv;
 };
 
 struct _ECategoriesClass
 {
-	GnomeDialogClass parent_class;
+	GtkDialogClass parent_class;
 };
 
 
-GtkType    e_categories_get_type   (void);
+GType      e_categories_get_type   (void);
 GtkWidget *e_categories_new        (const char  *categories);
 void       e_categories_construct  (ECategories *categories,
 				    const char  *initial_category_list);
