@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * gtk-combo-text.c - A combo box for selecting from a list.
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -22,12 +22,14 @@
 
 #include <config.h>
 #include <ctype.h>
+#include <gal/util/e-util.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtklist.h>
 #include <gtk/gtkscrolledwindow.h>
 #include "gtk-combo-text.h"
 
+#define PARENT_TYPE GTK_COMBO_BOX_TYPE
 static GtkObjectClass *gtk_combo_text_parent_class;
 
 static gboolean cb_pop_down (GtkWidget *w, GtkWidget *pop_down,
@@ -47,11 +49,19 @@ gtk_combo_text_destroy (GtkObject *object)
 		g_hash_table_destroy (ct->elements);
 		ct->elements = NULL;
 	}
-	gtk_signal_disconnect_by_func (GTK_OBJECT (ct),
-				       GTK_SIGNAL_FUNC (cb_pop_down), NULL);
-	gtk_signal_disconnect_by_func (GTK_OBJECT (ct->list),
-				       GTK_SIGNAL_FUNC (list_unselect_cb),
-				       (gpointer) ct);
+	if (ct->list != NULL) {
+		g_signal_handlers_disconnect_matched (ct,
+						      G_SIGNAL_MATCH_FUNC,
+						      0, 0, NULL,
+						      cb_pop_down, NULL);
+
+		g_signal_handlers_disconnect_matched (ct->list,
+						      G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL,
+						      list_unselect_cb, ct);
+		ct->list = NULL;
+	}
+
 	(*gtk_combo_text_parent_class->destroy) (object);
 }
 
@@ -59,7 +69,7 @@ static void
 gtk_combo_text_class_init (GtkObjectClass *object_class)
 {
 	object_class->destroy = &gtk_combo_text_destroy;
-	gtk_combo_text_parent_class = gtk_type_class (gtk_combo_box_get_type ());
+	gtk_combo_text_parent_class = g_type_class_ref (PARENT_TYPE);
 }
 
 static void
@@ -67,28 +77,12 @@ gtk_combo_text_init (GtkComboText *object)
 {
 }
 
-GtkType
-gtk_combo_text_get_type (void)
-{
-	static GtkType type = 0;
-
-	if (!type){
-		GtkTypeInfo info = {
-			"GtkComboText",
-			sizeof (GtkComboText),
-			sizeof (GtkComboTextClass),
-			(GtkClassInitFunc) gtk_combo_text_class_init,
-			(GtkObjectInitFunc) gtk_combo_text_init,
-			NULL, /* reserved 1 */
-			NULL, /* reserved 2 */
-			(GtkClassInitFunc) NULL
-		};
-
-		type = gtk_type_unique (gtk_combo_box_get_type (), &info);
-	}
-
-	return type;
-}
+E_MAKE_TYPE (gtk_combo_text,
+	     "GtkComboText",
+	     GtkComboText,
+	     gtk_combo_text_class_init,
+	     gtk_combo_text_init,
+	     PARENT_TYPE)
 
 static gint
 strcase_equal (gconstpointer v, gconstpointer v2)
@@ -178,8 +172,7 @@ list_select_cb (GtkWidget *list, GtkWidget *child, gpointer data)
 {
 	GtkComboText *combo = GTK_COMBO_TEXT (data);
 	GtkEntry *entry = GTK_ENTRY (combo->entry);
-	gchar *value = (gchar*) gtk_object_get_data
-		(GTK_OBJECT (child), "value");
+	gchar *value = (gchar*) g_object_get_data (G_OBJECT (child), "value");
 
 	g_return_if_fail (entry && value);
 
@@ -190,7 +183,7 @@ list_select_cb (GtkWidget *list, GtkWidget *child, gpointer data)
 	gtk_signal_handler_block_by_func (GTK_OBJECT (entry), 
 					  GTK_SIGNAL_FUNC (entry_activate_cb),
 					  (gpointer) combo);
-	gtk_signal_emit_by_name (GTK_OBJECT (entry), "activate");
+	g_signal_emit_by_name (entry, "activate");
 	gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry), 
 					  GTK_SIGNAL_FUNC (entry_activate_cb),
 					  (gpointer) combo);
@@ -302,16 +295,21 @@ cb_pop_down (GtkWidget *w, GtkWidget *pop_down, gpointer dummy)
 	return FALSE;
 }
 
-static void
-cb_remove_from_hash (GtkWidget *child, gpointer data)
-{
-	GtkComboText *ct = GTK_COMBO_TEXT (data);
+typedef struct {
+	GtkComboText *ct;
 	gchar *value;
+} WeakRefClosure;
+
+static void
+cb_remove_from_hash (gpointer data, GObject *where_object_was)
+{
+	WeakRefClosure *closure = data;
 	
-	if (ct->elements) {
-		value = gtk_object_get_data (GTK_OBJECT (child), "value");
-		g_hash_table_remove (ct->elements, value);
-	}
+	if (closure->ct->elements)
+		g_hash_table_remove (closure->ct->elements, closure->value);
+
+	g_free (closure->value);
+	g_free (closure);
 }
 
 void
@@ -319,6 +317,7 @@ gtk_combo_text_add_item (GtkComboText *ct,
 			 const gchar *item,
 			 const gchar *value)
 {
+	WeakRefClosure *weak_ref_closure;
 	GtkWidget *listitem;
 	gchar *value_copy;
 
@@ -332,17 +331,17 @@ gtk_combo_text_add_item (GtkComboText *ct,
 	listitem = gtk_list_item_new_with_label (item);
 	gtk_widget_show (listitem);
 
-	gtk_object_set_data_full (GTK_OBJECT (listitem), "value",
-				  value_copy, g_free);
-	gtk_signal_connect (GTK_OBJECT (listitem), "enter-notify-event",
-			    GTK_SIGNAL_FUNC (cb_enter),
-			    (gpointer) ct);
-	gtk_signal_connect (GTK_OBJECT (listitem), "leave-notify-event",
-			    GTK_SIGNAL_FUNC (cb_exit),
-			    (gpointer) ct);
-	gtk_signal_connect (GTK_OBJECT (listitem), "toggle",
-			    GTK_SIGNAL_FUNC (cb_toggle),
-			    (gpointer) ct);
+	g_object_set_data_full (G_OBJECT (listitem), "value",
+				value_copy, g_free);
+	g_signal_connect (listitem, "enter-notify-event",
+			  G_CALLBACK (cb_enter),
+			  (gpointer) ct);
+	g_signal_connect (listitem, "leave-notify-event",
+			  G_CALLBACK (cb_exit),
+			  (gpointer) ct);
+	g_signal_connect (listitem, "toggle",
+			  G_CALLBACK (cb_toggle),
+			  (gpointer) ct);
 
 	gtk_container_add (GTK_CONTAINER (ct->list),
 			   listitem);
@@ -350,9 +349,13 @@ gtk_combo_text_add_item (GtkComboText *ct,
 	g_hash_table_insert (ct->elements, (gpointer)value_copy,
 			     (gpointer) listitem);
 
-	gtk_signal_connect (GTK_OBJECT (listitem), "destroy",
-			    GTK_SIGNAL_FUNC (cb_remove_from_hash),
-			    (gpointer) ct);
+	weak_ref_closure = g_new (WeakRefClosure, 1);
+	weak_ref_closure->ct = ct;
+	weak_ref_closure->value = g_strdup (value_copy);
+	
+	g_object_weak_ref (G_OBJECT (listitem),
+			   cb_remove_from_hash,
+			   weak_ref_closure);
 }
 
 static void
@@ -399,23 +402,23 @@ gtk_combo_text_construct (GtkComboText *ct, gboolean const is_scrolled)
 	} else
 		display_widget = list;
 
-	gtk_signal_connect (GTK_OBJECT (entry), "activate",
-			    GTK_SIGNAL_FUNC (entry_activate_cb),
-			    (gpointer) ct);
-	gtk_signal_connect (GTK_OBJECT (list), "select-child",
-			    GTK_SIGNAL_FUNC (list_select_cb),
-			    (gpointer) ct);
-	gtk_signal_connect (GTK_OBJECT (list), "unselect-child",
-			    GTK_SIGNAL_FUNC (list_unselect_cb),
-			    (gpointer) ct);
-	gtk_signal_connect (GTK_OBJECT (list), "map",
-			    GTK_SIGNAL_FUNC (cb_list_mapped), NULL);
-
+	g_signal_connect (entry, "activate",
+			  G_CALLBACK (entry_activate_cb),
+			  ct);
+	g_signal_connect (list, "select-child",
+			  G_CALLBACK (list_select_cb),
+			  ct);
+	g_signal_connect (list, "unselect-child",
+			  G_CALLBACK (list_unselect_cb),
+			  ct);
+	g_signal_connect (list, "map",
+			  G_CALLBACK (cb_list_mapped), NULL);
+	
 	gtk_widget_show (display_widget);
 	gtk_widget_show (entry);
 	gtk_combo_box_construct (GTK_COMBO_BOX (ct), entry, display_widget);
-	gtk_signal_connect (GTK_OBJECT (ct), "pop_down_done",
-			    GTK_SIGNAL_FUNC (cb_pop_down), NULL);
+	g_signal_connect (ct, "pop_down_done",
+			  G_CALLBACK (cb_pop_down), NULL);
 }
 
 GtkWidget*
@@ -423,7 +426,7 @@ gtk_combo_text_new (gboolean const is_scrolled)
 {
 	GtkComboText *ct;
 
-	ct = gtk_type_new (gtk_combo_text_get_type ());
+	ct = g_object_new (GTK_COMBO_TEXT_TYPE, NULL);
 	gtk_combo_text_construct (ct, is_scrolled);
 	return GTK_WIDGET (ct);
 }
