@@ -1,3 +1,25 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* 
+ * gtk-combo-text.h - A combo box for selecting from a list.
+ * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * Authors:
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
+
 #ifndef _GTK_COMBO_TEXT_H
 #define _GTK_COMBO_TEXT_H
 
@@ -7,9 +29,10 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#define GTK_COMBO_TEXT(obj)	    GTK_CHECK_CAST (obj, gtk_combo_text_get_type (), GtkComboText)
-#define GTK_COMBO_TEXT_CLASS(klass) GTK_CHECK_CLASS_CAST (klass, gtk_combo_text_get_type (), GtkComboTextClass)
-#define GTK_IS_COMBO_TEXT(obj)      GTK_CHECK_TYPE (obj, gtk_combo_text_get_type ())
+#define GTK_COMBO_TEXT_TYPE         (gtk_combo_text_get_type ())
+#define GTK_COMBO_TEXT(obj)	    G_TYPE_CHECK_INSTANCE_CAST (obj, gtk_combo_text_get_type (), GtkComboText)
+#define GTK_COMBO_TEXT_CLASS(klass) G_TYPE_CHECK_CLASS_CAST (klass, gtk_combo_text_get_type (), GtkComboTextClass)
+#define GTK_IS_COMBO_TEXT(obj)      G_TYPE_CHECK_INSTANCE_TYPE (obj, gtk_combo_text_get_type ())
 
 typedef struct _GtkComboText	   GtkComboText;
 /* typedef struct _GtkComboTextPrivate GtkComboTextPrivate;*/
