@@ -266,6 +266,8 @@ color_combo_set_color (ColorCombo *cc, GdkColor *color)
 	 * will let the users of the combo know that the current color has
 	 * changed
 	 */
+	if (color != NULL)
+		gdk_rgb_find_color (gtk_widget_get_colormap (GTK_WIDGET (cc)), color);
 	color_palette_set_current_color (cc->palette, color);
 }
 
