@@ -54,7 +54,7 @@ main(int argc, char *argv[])
 
 	gnome_init ("DefineViewsExample", "DefineViewsExample", argc, argv);
 
-	glade_gnome_init();
+	glade_init();
 
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
